/**
 *
 */
package de.intevation.gnv.transition;

import java.util.ArrayList;
import java.util.Collection;

import org.apache.log4j.Logger;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import de.intevation.artifactdatabase.Config;

/**
 * @author Tim Englich <tim.englich@intevation.de>
 *
 */
public abstract class OutputTransitionBase extends TransitionBase implements
        OutputTransition {
    /**
     * the logger, used to log exceptions and additonaly information
     */
    private static Logger log = Logger.getLogger(OutputTransitionBase.class);
    
    protected Collection<OutputMode> outputModes = null;
    /**
     * Constructor
     */
    public OutputTransitionBase() {
        super();
    }

    /**
     * @see de.intevation.gnv.transition.OutputTransition#getOutputModes()
     */
    public Collection<OutputMode> getOutputModes() {
        log.debug("OutputTransitionBase.getOutputModes");
        return this.outputModes;
    }

    /**
     * @see de.intevation.gnv.transition.TransitionBase#setup(org.w3c.dom.Node)
     */
    @Override
    public void setup(Node configuration) {
        log.debug("OutputTransitionBase.setup");
        super.setup(configuration);
        NodeList outputModeList = Config.getNodeSetXPath(configuration, "outputsModes/outputsMode");
        if (outputModeList != null){
            log.debug(outputModeList.getLength()+ " were found.");
            this.outputModes = new ArrayList<OutputMode>(outputModeList.getLength());
            for (int i = 0; i < outputModeList.getLength(); i++){
                Node currentNode = outputModeList.item(i);
                String name  = Config.getStringXPath(currentNode, "@name");
                String description  = Config.getStringXPath(currentNode, "@description");
                String mimeType = Config.getStringXPath(currentNode, "@mime-type");
                OutputMode outputMode = new DefaultOutputMode(name, description, mimeType);
                log.debug(outputMode.toString());
                this.outputModes.add(outputMode);
                
            }
        }
    }

}
